/***************************************************************************************************

  DispLog.h - header file for DispLog.cpp

***************************************************************************************************/
#ifndef DispLogH
  #define DispLogH

  #define MAX_POS 200                                             // max date/time position

  class TDispLog : public TObject {
    public:
           __fastcall  TDispLog(void);                            // constructor
           __fastcall ~TDispLog(void);                            // destructor
      void __fastcall  AddLine(AnsiString);                       // add line to log or display
      void __fastcall  InitDisplay(TForm *, int, int, int, int);  // initialize display memo
      void __fastcall  RemoveDisplay(void);                       // remove the display memo
      void __fastcall  ClearDisplay(void);                        // remove all lines from memo

    __published:
      __property unsigned int MaxDispLines = { read = fMaxDispLines, write = fMaxDispLines   };
      __property AnsiString   LogFilename  = { read = fLogFilename,  write = SetLogFilename  };
      __property bool         LogLine      = { read = fLogLine,      write = SetLogLine      };
      __property bool         DisplayLine  = { read = fDisplayLine,  write = SetDisplayLine  };
      __property bool         AppendToLog  = { read = fAppendToLog,  write = SetAppendToLog  };
      __property bool         DisplayTime  = { read = fDisplayTime,  write = fDisplayTime    };
      __property bool         DisplayMSecs = { read = fDisplayMSecs, write = fDisplayMSecs   };
      __property bool         DisplayDate  = { read = fDisplayDate,  write = fDisplayDate    };
      __property bool         LogTime      = { read = fLogTime,      write = fLogTime        };
      __property bool         LogMSecs     = { read = fLogMSecs,     write = fLogMSecs       };
      __property bool         LogDate      = { read = fLogDate,      write = fLogDate        };
      __property unsigned int DisplayDTPos = { read = fDisplayDTPos, write = SetDisplayDTPos };
      __property unsigned int LogDTPos     = { read = fLogDTPos,     write = SetLogDTPos     };
      __property bool         KeepLogOpen  = { read = fKeepLogOpen,  write = SetKeepLogOpen  };
      __property bool         DispHorSBar  = { read = fDispHorSBar,  write = SetDispHorSBar  };
      __property bool         DispVerSBar  = { read = fDispVerSBar,  write = SetDispVerSBar  };
      __property AnsiString   SepString    = { read = fSepString,    write = fSepString      };

    protected:
      TMemo       *Memo;                         // memo used to display lines
      int          LogFileLines;                 // count of lines written to log file
      int          LogFileHandle;                // log file handle
      // property field variables
      unsigned int fMaxDispLines;                // max number of messages to keep in memo
      AnsiString   fLogFilename;                 // name of file to which to write log lines
      bool         fLogLine;                     // true if lines are logged
      bool         fDisplayLine;                 // true if lines are displayed
      bool         fAppendToLog;                 // true if existing log should be appended to
      bool         fDisplayTime;                 // display time at end of line
      bool         fDisplayMSecs;                // display milliseconds as part of time string
      bool         fDisplayDate;                 // display date at end of line
      bool         fLogTime;                     // log time at end of line
      bool         fLogMSecs;                    // log milliseconds as part of time string
      bool         fLogDate;                     // log date at end of line
      unsigned int fDisplayDTPos;                // position of date and/or time on display
      unsigned int fLogDTPos;                    // positoin of date and/or time in log
      bool         fKeepLogOpen;                 // keep log file open between writes
      bool         fDispHorSBar;                 // set to display a horizontal scroll bar in memo
      bool         fDispVerSBar;                 // set to display a vertical scroll bar in memo
      AnsiString   fSepString;                   // string seperates date and time from line

      void         __fastcall WriteToLog(AnsiString);
      void         __fastcall AddDateTime(AnsiString *, bool, bool, bool, int);
      void         __fastcall OpenLogFile(void);
      void         __fastcall CloseLogFile(void);
      AnsiString   __fastcall GetSystemErrorMessage(void);
      void         __fastcall SetScrollBars(void);
      void         __fastcall PadString(AnsiString *, int);
      // property get/set functions
      void         __fastcall SetLogFilename(AnsiString);
      void         __fastcall SetLogLine(bool);
      void         __fastcall SetDisplayLine(bool);
      void         __fastcall SetAppendToLog(bool);
      void         __fastcall SetDisplayDTPos(unsigned int);
      void         __fastcall SetLogDTPos(unsigned int);
      void         __fastcall SetKeepLogOpen(bool);
      void         __fastcall SetDispHorSBar(bool);
      void         __fastcall SetDispVerSBar(bool);
  };
#endif

